# KjmaroTools
KjmaroTools is a Python library containing several tools developed for simplification and to be used in other fjmaro libraries.

- The source code can be checked out from the github repository with: git clone git://github.com/fjmaro/KjmaroTools.git

![Python Logo](https://www.python.org/static/community_logos/python-logo.png "Python")
